@@ -76,18 +76,28 @@ https://raw.github.com/TiddlySpace/ts.js/master/src/ts.js
 		if(msgArea.length === 0) {
 			msgArea = $('<div class="messageArea" />').prependTo(form);
 		}
-		msgArea.html(msg || ts.locale.error).show(100);
+		msgArea
+			.append( 
+				$('<button></button')
+					.html("&times;")
+					.addClass("close-btn")
+					.attr("title", "close notification")
+					.data("parent-class", "messageArea")
+					.click( function() { resetMessage(form) } )
+			)
+			.append( $('<p></p>').html(msg || ts.locale.error) )
+			.show(100);
 		if(error) {
 			msgArea.addClass("error annotation");
+			var container = $("<div />").appendTo(msgArea)[0];
+			$("<a />").text("Try again?").click(function() {
+				resetMessage(form);
+				$('input', form)[0].focus();
+			}).appendTo(container);
 		}
 		if(options.annotate) {
 			$(options.annotate, form).addClass("annotation");
 		}
-		var container = $("<div />").appendTo(msgArea)[0];
-		var label = error ? ts.locale.tryAgain : ts.locale.success;
-		$("<a />").text(label).click(function() {
-			resetMessage(form);
-		}).appendTo(container);
 	}
 
 	/*
@@ -638,13 +648,12 @@ https://raw.github.com/TiddlySpace/ts.js/master/src/ts.js
 					$(list).removeClass("ts-loading").empty();
 					for(i = 0; i < inclusions.length; i += 1) {
 						item = $("<li />").appendTo(list)[0];
-						$("<a />").text(inclusions[i]).attr("href",
-								ts.getHost(inclusions[i])).appendTo(item);
-						$("<button />").addClass("delete").
-							data("inclusion", inclusions[i]).
-							attr("inclusion", inclusions[i]).
-							text("remove").click(removeInclusion).
-							appendTo(item);
+						$("<a />")
+							.text(inclusions[i])
+							.attr("href", ts.getHost(inclusions[i]))
+							.attr("title", "visit icluded space")
+							.appendTo(item);
+						addDeleteBtn("inclusion", inclusions[i], item, removeInclusion);
 					}
 				};
 				var errback = function(xhr, error, exc) {
@@ -685,13 +694,13 @@ https://raw.github.com/TiddlySpace/ts.js/master/src/ts.js
 					members = members.sort();
 					for(i = 0; i < members.length; i += 1) {
 						item = $("<li />").appendTo(list)[0];
-						$("<a />").text(members[i]).attr("href",
-								ts.getHost(members[i])).appendTo(item);
+						$("<a />")
+							.text(members[i])
+							.attr("href", ts.getHost(members[i]))
+							.attr("title", "visit member's home space")
+							.appendTo(item);
 						if(members.length > 1) {
-							$("<button />").addClass("delete").
-								data("member", members[i]).
-								attr("member", members[i]).text("remove").
-								click(removeMember).appendTo(item);
+							addDeleteBtn("member", members[i], item, removeMember);
 						}
 					}
 				};
@@ -705,6 +714,17 @@ https://raw.github.com/TiddlySpace/ts.js/master/src/ts.js
 			}
 		}
 	};
+
+	function addDeleteBtn(type, data, item, cb) {
+		$("<button />")
+			.addClass("delete")
+			.data(type, data)
+			.attr("title", "remove " + type)
+			.html("&times;")
+			.click(cb)
+			.appendTo(item);
+	}
+
 	ts.parseParameters = parseParameters;
 	window.ts = {
 		init: ts.init
