@@ -165,8 +165,7 @@ var followMacro = config.macros.followTiddlers = {
 		var user = params[1] || false;
 		if(tid) {
 			followMacro.makeButton(place, {
-				url: "/search?q=title:%22"
-                                    + encodeURIComponent(title) + "%22",
+				url: "/search?q=title:%22" + encodeURIComponent(title) + "%22",
 				containingTiddler: containingTiddler,
 				blacklisted: followMacro.getBlacklist(), title: title, user: user,
 				consultFollowRelationship: (args.follow &&
@@ -365,7 +364,7 @@ var scanMacro = config.macros.tsScan = {
 					scanMacro._scanCallback(place, tiddlers, options);
 				};
 				if(scanMacro.scanned[url] && scanMacro.scanned[url].callbacks) {
-					scanMacro.scanned[url].callbacks.push(callback)
+					scanMacro.scanned[url].callbacks.push(callback);
 				} else {
 					scanMacro.scanned[url] = {
 						callbacks: [callback]
@@ -509,7 +508,7 @@ var linkedMacro = config.macros.linkedTiddlers = {
 				consultFollowRelationship: args.follow ? true : false });
 		}
 	}
-}
+};
 
 if(config.options.chkFollowTiddlersIsLinkedTiddlers) {
 	merge(config.macros.followTiddlers, config.macros.linkedTiddlers);
